.. vim: set fileencoding=utf-8 :


============
 Python API
============

Database
--------

.. automodule:: database
   :members:


Pre-processor
-------------

.. automodule:: preprocessor
   :members:


Machine Learning Algorithm
--------------------------

.. automodule:: algorithm
   :members:

Analysis
--------

.. automodule:: evaluator
   :members:
